@@ -13,11 +13,12 @@
 # limitations under the License.
 
 import copy
+import json
 import tempfile
-from unittest import mock
+import uuid
 
 import jsonschema
-from oslo_serialization import jsonutils as json
+import mock
 from oslo_utils import uuidutils
 
 from sahara import context
@@ -28,7 +29,7 @@ from sahara.tests.unit.db.templates import common as c
 
 cluster_json = {
     "plugin_name": "vanilla",
-    "hadoop_version": "2.7.1",
+    "hadoop_version": "2.6.0",
     "node_groups": [
         {
             "name": "worker",
@@ -48,7 +49,7 @@ cluster_json = {
 
 master_json = {
     "plugin_name": "vanilla",
-    "hadoop_version": "2.7.1",
+    "hadoop_version": "2.6.0",
     "node_processes": [
         "namenode",
         "resourcemanager",
@@ -56,29 +57,24 @@ master_json = {
     ],
     "name": "vanilla-260-default-master",
     "floating_ip_pool": "{floating_ip_pool}",
-    "flavor_id": "{flavor_id}",
-    "auto_security_group": "{auto_security_group}",
-    'security_groups': "{security_groups}"
+    "flavor_id": "{flavor_id}"
 }
 
 worker_json = {
     "plugin_name": "vanilla",
-    "hadoop_version": "2.7.1",
+    "hadoop_version": "2.6.0",
     "node_processes": [
         "nodemanager",
         "datanode"
     ],
     "name": "vanilla-260-default-worker",
     "floating_ip_pool": "{floating_ip_pool}",
-    "flavor_id": "{flavor_id}",
-    "auto_security_group": "{auto_security_group}",
-    'security_groups': "{security_groups}"
+    "flavor_id": "{flavor_id}"
 }
 
 
 class Config(c.Config):
-    def __init__(self, option_values=None):
-        option_values = option_values or {}
+    def __init__(self, option_values={}):
         if "name" not in option_values:
             option_values["name"] = "update"
         super(Config, self).__init__(option_values)
@@ -209,24 +205,24 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
                    "floating_ip_pool": None}
         template_api.substitute_config_values(configs, ngt, "/path")
         self.assertEqual("2", ngt["flavor_id"])
-        self.assertIsNone(ngt["floating_ip_pool"])
+        self.assertNotIn("floating_ip_pool", ngt)
 
     def test_substitute_config_values_clt(self):
         clt = copy.copy(c.SAMPLE_CLT)
         clt["neutron_management_network"] = "{neutron_management_network}"
         clt["default_image_id"] = "{default_image_id}"
 
-        netid = uuidutils.generate_uuid()
+        netid = str(uuid.uuid4())
         configs = {"neutron_management_network": netid,
                    "default_image_id": None}
         template_api.substitute_config_values(configs, clt, "/path")
         self.assertEqual(netid, clt["neutron_management_network"])
-        self.assertIsNone(clt["default_image_id"])
+        self.assertNotIn("default_image_id", clt)
 
     def _write_files(self, tempdir, templates):
         files = []
         for template in templates:
-            fp = tempfile.NamedTemporaryFile(suffix=".json", mode="w",
+            fp = tempfile.NamedTemporaryFile(suffix=".json",
                                              dir=tempdir, delete=False)
             json.dump(template, fp)
             files.append(fp.name)
@@ -246,8 +242,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         files = self._write_files(
             tempdir, [cluster_json, master_json, worker_json, some_other_json])
 
-        get_configs.return_value = {"flavor_id": '2', 'security_groups': [],
-                                    'auto_security_group': False}
+        get_configs.return_value = {"flavor_id": 2}
         option_values = {"plugin_name": None,
                          "plugin_version": None}
         template_api.set_conf(Config(option_values))
@@ -262,14 +257,21 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         # Plugin name/version filtering applied
         option_values = {"plugin_name": "vanilla",
-                         "plugin_version": "2.7.1"}
+                         "plugin_version": "2.6.0"}
         template_api.set_conf(Config(option_values))
         ng_templates, cl_templates = template_api.process_files(tempdir, files)
         self.assertEqual(1, len(cl_templates))
         self.assertEqual(2, len(ng_templates))
 
+        option_values = {"plugin_name": "vanilla",
+                         "plugin_version": "1.2.1"}
+        template_api.set_conf(Config(option_values))
+        ng_templates, cl_templates = template_api.process_files(tempdir, files)
+        self.assertEqual(0, len(cl_templates))
+        self.assertEqual(0, len(ng_templates))
+
         option_values = {"plugin_name": "hdp",
-                         "plugin_version": "2.7.1"}
+                         "plugin_version": "2.6.0"}
         template_api.set_conf(Config(option_values))
         ng_templates, cl_templates = template_api.process_files(tempdir, files)
         self.assertEqual(0, len(cl_templates))
@@ -285,12 +287,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         files = self._write_files(
             tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            'security_groups': [],
-            'auto_security_group': False
-        }
-
+        get_configs.return_value = {"flavor_id": 2}
         option_values = {"plugin_name": None,
                          "plugin_version": None}
         template_api.set_conf(Config(option_values))
@@ -316,8 +313,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         files = self._write_files(
             tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {"flavor_id": '2', 'security_groups': [],
-                                    'auto_security_group': False}
+        get_configs.return_value = {"flavor_id": 2}
         option_values = {"plugin_name": None,
                          "plugin_version": None}
         template_api.set_conf(Config(option_values))
@@ -325,7 +321,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         # Invalid JSON should cause all files to be skipped
         fp = tempfile.NamedTemporaryFile(suffix=".json",
                                          dir=tempdir, delete=False)
-        fp.write(b"not json")
+        fp.write("not json")
         files += [fp.name]
         fp.close()
         ng_templates, cl_templates = template_api.process_files(tempdir, files)
@@ -386,9 +382,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.infos)
 
         self.api.node_group_template_destroy(ctx, new["id"],
-                                             ignore_prot_on_def=True)
+                                             ignore_default=True)
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_prot_on_def=True)
+                                             ignore_default=True)
 
     @mock.patch("sahara.conductor.API.node_group_template_update")
     @mock.patch("sahara.db.templates.api.reverse_node_group_template_creates")
@@ -431,9 +427,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.node_group_template_destroy(ctx, new["id"],
-                                             ignore_prot_on_def=True)
+                                             ignore_default=True)
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_prot_on_def=True)
+                                             ignore_default=True)
 
     @mock.patch("sahara.conductor.API.node_group_template_create")
     @mock.patch("sahara.db.templates.api.reverse_node_group_template_creates")
@@ -475,7 +471,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_prot_on_def=True)
+                                             ignore_default=True)
 
     def test_add_cluster_templates(self):
         self.logger.clear_log()
@@ -511,9 +507,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.infos)
 
         self.api.cluster_template_destroy(ctx, new["id"],
-                                          ignore_prot_on_def=True)
+                                          ignore_default=True)
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_prot_on_def=True)
+                                          ignore_default=True)
 
     @mock.patch("sahara.conductor.API.cluster_template_update")
     @mock.patch("sahara.db.templates.api.reverse_cluster_template_creates")
@@ -556,9 +552,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.cluster_template_destroy(ctx, new["id"],
-                                          ignore_prot_on_def=True)
+                                          ignore_default=True)
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_prot_on_def=True)
+                                          ignore_default=True)
 
     @mock.patch("sahara.conductor.API.cluster_template_create")
     @mock.patch("sahara.db.templates.api.reverse_cluster_template_creates")
@@ -604,11 +600,11 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_prot_on_def=True)
+                                          ignore_default=True)
 
     @mock.patch("sahara.db.templates.api.get_configs")
     @mock.patch("sahara.db.templates.api.add_config_section_for_template")
-    def test_do_update_trash(self, add_config, get_configs):
+    def test_do_update(self, add_config, get_configs):
         self.logger.clear_log()
         ctx = context.ctx()
 
@@ -616,19 +612,15 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         self._write_files(tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            "neutron_management_network": uuidutils.generate_uuid(),
-            'auto_security_group': True,
-            'security_groups': [],
-        }
-
+        get_configs.return_value = {"flavor_id": 2,
+                                    "neutron_management_network": uuid.uuid4()}
         option_values = {"tenant_id": ctx.tenant_id,
                          "directory": tempdir,
                          "norecurse": None,
                          "plugin_name": None,
                          "plugin_version": None}
         template_api.set_conf(Config(option_values))
+
         template_api.do_update()
 
         ngs = self.api.node_group_template_get_all(ctx)
@@ -653,11 +645,8 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         self._write_files(tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            "neutron_management_network": uuidutils.generate_uuid()
-        }
-
+        get_configs.return_value = {"flavor_id": 2,
+                                    "neutron_management_network": uuid.uuid4()}
         option_values = {"tenant_id": ctx.tenant_id,
                          "directory": tempdir,
                          "norecurse": None,
@@ -691,10 +680,8 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         self._write_files(tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            "neutron_management_network": uuidutils.generate_uuid()
-        }
+        get_configs.return_value = {"flavor_id": 2,
+                                    "neutron_management_network": uuid.uuid4()}
         option_values = {"tenant_id": ctx.tenant_id,
                          "directory": tempdir,
                          "norecurse": None,
@@ -728,11 +715,8 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         self._write_files(tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            "neutron_management_network": uuidutils.generate_uuid()
-        }
-
+        get_configs.return_value = {"flavor_id": 2,
+                                    "neutron_management_network": uuid.uuid4()}
         option_values = {"tenant_id": ctx.tenant_id,
                          "directory": tempdir,
                          "norecurse": None,
@@ -772,11 +756,8 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
 
         self._write_files(tempdir, [cluster_json, master_json, worker_json])
 
-        get_configs.return_value = {
-            "flavor_id": '2',
-            "neutron_management_network": uuidutils.generate_uuid()
-        }
-
+        get_configs.return_value = {"flavor_id": 2,
+                                    "neutron_management_network": uuid.uuid4()}
         option_values = {"tenant_id": ctx.tenant_id,
                          "directory": tempdir,
                          "norecurse": None,
