@@ -77,25 +77,6 @@ class ValidationTest(base.SaharaTestCase):
         with testtools.ExpectedException(ex.InvalidComponentCountException):
             self.pl.validate(cl)
 
-        self.ng.append(tu.make_ng_dict("hi", "f1", ["hiveserver"], 0))
-        self.ng.append(tu.make_ng_dict("sh", "f1",
-                                       ["spark history server"], 0))
-
-        self._validate_case(1, 1, 0, 0, 3, 0, 0, 1, 0)
-        self._validate_case(1, 1, 0, 0, 3, 0, 0, 0, 1)
-
-        with testtools.ExpectedException(ex.InvalidComponentCountException):
-            self._validate_case(1, 1, 0, 0, 3, 0, 0, 2, 0)
-        with testtools.ExpectedException(ex.InvalidComponentCountException):
-            self._validate_case(1, 1, 0, 0, 3, 0, 0, 0, 2)
-
-        self.ng.append(tu.make_ng_dict("zk", "f1", ["zookeeper"], 0))
-
-        self._validate_case(1, 1, 0, 0, 3, 0, 0, 1, 1, 3)
-
-        with testtools.ExpectedException(ex.InvalidComponentCountException):
-            self._validate_case(1, 1, 0, 0, 3, 0, 0, 1, 1, 2)
-
     def _create_cluster(self, *args, **kwargs):
         lst = []
         for i in range(0, len(args)):
@@ -103,7 +84,7 @@ class ValidationTest(base.SaharaTestCase):
             lst.append(self.ng[i])
 
         return tu.create_cluster("cluster1", "tenant1", "vanilla",
-                                 "2.7.1", lst, **kwargs)
+                                 "2.6.0", lst, **kwargs)
 
     def _validate_case(self, *args):
         cl = self._create_cluster(*args)
